@@ -9,3 +9,6 @@ SECOND = 1
 MINUTE = 60
 HOUR = 3600
 DAY = 86400
+WEEK = 604800
+MONTH = 2678400
+YEAR = 31536000
